#ifndef _STM32YYXX_LL_FMC_H_
#define _STM32YYXX_LL_FMC_H_
/* LL raised several warnings, ignore them */
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wunused-parameter"
#pragma GCC diagnostic ignored "-Wstrict-aliasing"

#ifdef STM32F3xx
  #include "stm32f3xx_ll_fmc.h"
#endif
#ifdef STM32F4xx
  #include "stm32f4xx_ll_fmc.h"
#endif
#ifdef STM32F7xx
  #include "stm32f7xx_ll_fmc.h"
#endif
#ifdef STM32G4xx
  #include "stm32g4xx_ll_fmc.h"
#endif
#ifdef STM32H7xx
  #include "stm32h7xx_ll_fmc.h"
#endif
#ifdef STM32L4xx
  #include "stm32l4xx_ll_fmc.h"
#endif
#ifdef STM32L5xx
  #include "stm32l5xx_ll_fmc.h"
#endif
#ifdef STM32MP1xx
  #include "stm32mp1xx_ll_fmc.h"
#endif
#pragma GCC diagnostic pop
#endif /* _STM32YYXX_LL_FMC_H_ */
